diff --git a/.github/workflows/rust.yml b/.github/workflows/rust.yml
index b2505e80d..a0eefd3a9 100644
--- a/.github/workflows/rust.yml
+++ b/.github/workflows/rust.yml
@@ -2,24 +2,23 @@ name: Rust
 
 on:
   push:
-    branches: [ master ]
+    branches: [master]
   pull_request:
-    branches: [ master ]
+    branches: [master]
 
 env:
   CARGO_TERM_COLOR: always
 
 jobs:
   build:
-
     runs-on: ubuntu-latest
 
     steps:
-    - uses: actions/checkout@v2
-    - uses: actions-rs/toolchain@v1
-      with:
-        toolchain: nightly
-        target: thumbv7em-none-eabihf
-        override: true
-    - name: Build
-      run: ./test-build.sh
+      - uses: actions/checkout@v2
+      - uses: actions-rs/toolchain@v1
+        with:
+          toolchain: nightly
+          target: thumbv7em-none-eabi
+          override: true
+      - name: Build
+        run: ./test-build.sh
diff --git a/test-build.sh b/test-build.sh
index a3b5e8dfc..ae603b289 100755
--- a/test-build.sh
+++ b/test-build.sh
@@ -3,20 +3,20 @@
 set -euxo pipefail
 
 # examples
-(cd examples; cargo build --target thumbv7em-none-eabihf --bins)
+(cd examples; cargo build --target thumbv7em-none-eabi --bins)
 
 # embassy
-(cd embassy; cargo build --target thumbv7em-none-eabihf)
-(cd embassy; cargo build --target thumbv7em-none-eabihf --features log)
-(cd embassy; cargo build --target thumbv7em-none-eabihf --features defmt)
+(cd embassy; cargo build --target thumbv7em-none-eabi)
+(cd embassy; cargo build --target thumbv7em-none-eabi --features log)
+(cd embassy; cargo build --target thumbv7em-none-eabi --features defmt)
 
 # embassy-nrf
 (cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52810)
-#(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52811)  # nrf52811-hal doesn't exist yet
-(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52832)
-(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52833)
-(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52840)
+#(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52811)  # nrf52811-hal doesn't exist yet
+(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52832)
+(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52833)
+(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52840)
 
-(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52840,log)
-(cd embassy-nrf; cargo build --target thumbv7em-none-eabihf --features 52840,defmt)
+(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52840,log)
+(cd embassy-nrf; cargo build --target thumbv7em-none-eabi --features 52840,defmt)